# -*- coding: utf-8 -*-

from ..utils.encoding import encode_tx_hash


class TxHash:
    def __init__(self, th):
        self.__tx_hash = th

    def __str__(self):
        return encode_tx_hash(self.__tx_hash)

    def __bytes__(self):
        return self.__tx_hash



# -*- coding: utf-8 -*-

import json
import enum

from ..utils.encoding import encode_tx_hash, encode_address
from ..grpc.rpc_pb2 import CommitResult
from ..status.commit_status import CommitStatus
from ..status.tx_result_status import TxResultStatus
from ..grpc.blockchain_pb2 import Receipt


@enum.unique
class TxResultType(enum.Enum):
    COMMIT_RESULT = 0
    RECEIPT = 1


class TxResult:
    def __init__(self, result, tx=None):
        self.tx = tx
        self.__result = result

        if type(result) == Receipt:
            self.__type = TxResultType.RECEIPT
            try:
                self.status = TxResultStatus(result.status)
                self.detail = result.ret
            except:
                self.status = TxResultStatus.ERROR
                self.detail = result.status
            self.contract_address = encode_address(result.contractAddress)

            """
            if result.ret is None or 0 == len(result.ret):
                self.status = TxResultStatus.ERROR
                if 'CREATED' != result.status:
                    self.detail = result.status
            """
        elif type(result) == CommitResult:
            self.__type = TxResultType.COMMIT_RESULT
            self.tx_id = encode_tx_hash(self.__result.hash)
            self.status = CommitStatus(self.__result.error)
            self.detail = self.__result.detail
            self.contract_address = None

    @property
    def type(self):
        return self.__type

    def __str__(self):
        result = {
            'tx_id': self.tx_id,
            'status': self.status.name,
            'detail': self.detail,
            'contract_address': self.contract_address
        }
        return json.dumps(result, indent=2)



# -*- coding: utf-8 -*-

from ..utils.encoding import encode_block_hash, decode_block_hash


class BlockHash:
    def __init__(self, bh):
        if isinstance(bh, str):
            bh = decode_block_hash(bh)
        self.__block_hash = bh

    @property
    def value(self):
        return self.__block_hash

    def __bytes__(self):
        return self.__block_hash

    def __str__(self):
        return encode_block_hash(self.__block_hash)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rpc.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import blockchain_pb2 as blockchain__pb2
from . import account_pb2 as account__pb2
from . import node_pb2 as node__pb2
from . import p2p_pb2 as p2p__pb2
from . import metric_pb2 as metric__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rpc.proto',
  package='types',
  syntax='proto3',
  serialized_options=_b('Z\036github.com/aergoio/aergo/types'),
  serialized_pb=_b('\n\trpc.proto\x12\x05types\x1a\x10\x62lockchain.proto\x1a\raccount.proto\x1a\nnode.proto\x1a\tp2p.proto\x1a\x0cmetric.proto\"t\n\x10\x42lockchainStatus\x12\x17\n\x0f\x62\x65st_block_hash\x18\x01 \x01(\x0c\x12\x13\n\x0b\x62\x65st_height\x18\x02 \x01(\x04\x12\x16\n\x0e\x63onsensus_info\x18\x03 \x01(\t\x12\x1a\n\x12\x62\x65st_chain_id_hash\x18\x04 \x01(\x0c\"L\n\x07\x43hainId\x12\r\n\x05magic\x18\x01 \x01(\t\x12\x0e\n\x06public\x18\x02 \x01(\x08\x12\x0f\n\x07mainnet\x18\x03 \x01(\x08\x12\x11\n\tconsensus\x18\x04 \x01(\t\"\xb5\x01\n\tChainInfo\x12\x1a\n\x02id\x18\x01 \x01(\x0b\x32\x0e.types.ChainId\x12\x10\n\x08\x62pNumber\x18\x02 \x01(\r\x12\x14\n\x0cmaxblocksize\x18\x03 \x01(\x04\x12\x11\n\tmaxtokens\x18\x04 \x01(\x0c\x12\x16\n\x0estakingminimum\x18\x05 \x01(\x0c\x12\x14\n\x0ctotalstaking\x18\x06 \x01(\x0c\x12\x10\n\x08gasprice\x18\x07 \x01(\x0c\x12\x11\n\tnameprice\x18\x08 \x01(\x0c\"E\n\x05Input\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x03(\x0c\x12\r\n\x05value\x18\x03 \x01(\x0c\x12\x0e\n\x06script\x18\x04 \x01(\x0c\"G\n\x06Output\x12\r\n\x05index\x18\x01 \x01(\r\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0c\x12\r\n\x05value\x18\x03 \x01(\x0c\x12\x0e\n\x06script\x18\x04 \x01(\x0c\"\x07\n\x05\x45mpty\"\x1c\n\x0bSingleBytes\x12\r\n\x05value\x18\x01 \x01(\x0c\"\x1f\n\x0e\x41\x63\x63ountAddress\x12\r\n\x05value\x18\x01 \x01(\x0c\"C\n\x0e\x41\x63\x63ountAndRoot\x12\x0f\n\x07\x41\x63\x63ount\x18\x01 \x01(\x0c\x12\x0c\n\x04Root\x18\x02 \x01(\x0c\x12\x12\n\nCompressed\x18\x03 \x01(\x08\"\x99\x01\n\x04Peer\x12#\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x12.types.PeerAddress\x12(\n\tbestblock\x18\x02 \x01(\x0b\x32\x15.types.NewBlockNotice\x12\r\n\x05state\x18\x03 \x01(\x05\x12\x0e\n\x06hidden\x18\x04 \x01(\x08\x12\x11\n\tlashCheck\x18\x05 \x01(\x03\x12\x10\n\x08selfpeer\x18\x06 \x01(\x08\"&\n\x08PeerList\x12\x1a\n\x05peers\x18\x01 \x03(\x0b\x32\x0b.types.Peer\"U\n\nListParams\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x0e\n\x06height\x18\x02 \x01(\x04\x12\x0c\n\x04size\x18\x03 \x01(\r\x12\x0e\n\x06offset\x18\x04 \x01(\r\x12\x0b\n\x03\x61sc\x18\x05 \x01(\x08\"*\n\nPageParams\x12\x0e\n\x06offset\x18\x01 \x01(\r\x12\x0c\n\x04size\x18\x02 \x01(\r\"]\n\x0e\x42lockBodyPaged\x12\r\n\x05total\x18\x01 \x01(\r\x12\x0e\n\x06offset\x18\x02 \x01(\r\x12\x0c\n\x04size\x18\x03 \x01(\r\x12\x1e\n\x04\x62ody\x18\x04 \x01(\x0b\x32\x10.types.BlockBody\"J\n\x0f\x42lockBodyParams\x12\x14\n\x0chashornumber\x18\x01 \x01(\x0c\x12!\n\x06paging\x18\x02 \x01(\x0b\x32\x11.types.PageParams\"/\n\x0f\x42lockHeaderList\x12\x1c\n\x06\x62locks\x18\x01 \x03(\x0b\x32\x0c.types.Block\"R\n\rBlockMetadata\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\"\n\x06header\x18\x02 \x01(\x0b\x32\x12.types.BlockHeader\x12\x0f\n\x07txcount\x18\x03 \x01(\x05\"9\n\x11\x42lockMetadataList\x12$\n\x06\x62locks\x18\x01 \x03(\x0b\x32\x14.types.BlockMetadata\"P\n\x0c\x43ommitResult\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\"\n\x05\x65rror\x18\x02 \x01(\x0e\x32\x13.types.CommitStatus\x12\x0e\n\x06\x64\x65tail\x18\x03 \x01(\t\"8\n\x10\x43ommitResultList\x12$\n\x07results\x18\x01 \x03(\x0b\x32\x13.types.CommitResult\"I\n\x0cVerifyResult\x12\x15\n\x02tx\x18\x01 \x01(\x0b\x32\t.types.Tx\x12\"\n\x05\x65rror\x18\x02 \x01(\x0e\x32\x13.types.VerifyStatus\"?\n\x08Personal\x12\x12\n\npassphrase\x18\x01 \x01(\t\x12\x1f\n\x07\x61\x63\x63ount\x18\x02 \x01(\x0b\x32\x0e.types.Account\"Q\n\x0cImportFormat\x12\x1f\n\x03wif\x18\x01 \x01(\x0b\x32\x12.types.SingleBytes\x12\x0f\n\x07oldpass\x18\x02 \x01(\t\x12\x0f\n\x07newpass\x18\x03 \x01(\t\"\'\n\x07Staking\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x0c\x12\x0c\n\x04when\x18\x02 \x01(\x04\")\n\x04Vote\x12\x11\n\tcandidate\x18\x01 \x01(\x0c\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x0c\"\'\n\nVoteParams\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\r\"S\n\x0f\x41\x63\x63ountVoteInfo\x12\x1f\n\x07staking\x18\x01 \x01(\x0b\x32\x0e.types.Staking\x12\x1f\n\x06voting\x18\x02 \x03(\x0b\x32\x0f.types.VoteInfo\"*\n\x08VoteInfo\x12\n\n\x02id\x18\x02 \x01(\t\x12\x12\n\ncandidates\x18\x03 \x03(\t\"2\n\x08VoteList\x12\x1a\n\x05votes\x18\x01 \x03(\x0b\x32\x0b.types.Vote\x12\n\n\x02id\x18\x02 \x01(\t\"-\n\x07NodeReq\x12\x0f\n\x07timeout\x18\x01 \x01(\x0c\x12\x11\n\tcomponent\x18\x02 \x01(\x0c\"\x14\n\x04Name\x12\x0c\n\x04name\x18\x01 \x01(\t\"I\n\x08NameInfo\x12\x19\n\x04name\x18\x01 \x01(\x0b\x32\x0b.types.Name\x12\r\n\x05owner\x18\x02 \x01(\x0c\x12\x13\n\x0b\x64\x65stination\x18\x03 \x01(\x0c\"1\n\x0bPeersParams\x12\x10\n\x08noHidden\x18\x01 \x01(\x08\x12\x10\n\x08showSelf\x18\x02 \x01(\x08\")\n\tEventList\x12\x1c\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x0c.types.Event\"8\n\rConsensusInfo\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0c\n\x04info\x18\x02 \x01(\t\x12\x0b\n\x03\x62ps\x18\x03 \x03(\t*\xd2\x01\n\x0c\x43ommitStatus\x12\t\n\x05TX_OK\x10\x00\x12\x14\n\x10TX_NONCE_TOO_LOW\x10\x01\x12\x15\n\x11TX_ALREADY_EXISTS\x10\x02\x12\x13\n\x0fTX_INVALID_HASH\x10\x03\x12\x13\n\x0fTX_INVALID_SIGN\x10\x04\x12\x15\n\x11TX_INVALID_FORMAT\x10\x05\x12\x1b\n\x17TX_INSUFFICIENT_BALANCE\x10\x06\x12\x15\n\x11TX_HAS_SAME_NONCE\x10\x07\x12\x15\n\x11TX_INTERNAL_ERROR\x10\t*f\n\x0cVerifyStatus\x12\x14\n\x10VERIFY_STATUS_OK\x10\x00\x12 \n\x1cVERIFY_STATUS_SIGN_NOT_MATCH\x10\x01\x12\x1e\n\x1aVERIFY_STATUS_INVALID_HASH\x10\x02\x32\xdb\x0f\n\x0f\x41\x65rgoRPCService\x12\x31\n\tNodeState\x12\x0e.types.NodeReq\x1a\x12.types.SingleBytes\"\x00\x12\x31\n\x06Metric\x12\x15.types.MetricsRequest\x1a\x0e.types.Metrics\"\x00\x12\x35\n\nBlockchain\x12\x0c.types.Empty\x1a\x17.types.BlockchainStatus\"\x00\x12\x30\n\x0cGetChainInfo\x12\x0c.types.Empty\x1a\x10.types.ChainInfo\"\x00\x12?\n\x10ListBlockHeaders\x12\x11.types.ListParams\x1a\x16.types.BlockHeaderList\"\x00\x12\x42\n\x11ListBlockMetadata\x12\x11.types.ListParams\x1a\x18.types.BlockMetadataList\"\x00\x12\x31\n\x0fListBlockStream\x12\x0c.types.Empty\x1a\x0c.types.Block\"\x00\x30\x01\x12\x41\n\x17ListBlockMetadataStream\x12\x0c.types.Empty\x1a\x14.types.BlockMetadata\"\x00\x30\x01\x12.\n\x08GetBlock\x12\x12.types.SingleBytes\x1a\x0c.types.Block\"\x00\x12>\n\x10GetBlockMetadata\x12\x12.types.SingleBytes\x1a\x14.types.BlockMetadata\"\x00\x12?\n\x0cGetBlockBody\x12\x16.types.BlockBodyParams\x1a\x15.types.BlockBodyPaged\"\x00\x12(\n\x05GetTX\x12\x12.types.SingleBytes\x1a\t.types.Tx\"\x00\x12\x34\n\nGetBlockTX\x12\x12.types.SingleBytes\x1a\x10.types.TxInBlock\"\x00\x12\x32\n\nGetReceipt\x12\x12.types.SingleBytes\x1a\x0e.types.Receipt\"\x00\x12*\n\x06GetABI\x12\x12.types.SingleBytes\x1a\n.types.ABI\"\x00\x12*\n\x06SendTX\x12\t.types.Tx\x1a\x13.types.CommitResult\"\x00\x12 \n\x06SignTX\x12\t.types.Tx\x1a\t.types.Tx\"\x00\x12,\n\x08VerifyTX\x12\t.types.Tx\x1a\x13.types.VerifyResult\"\x00\x12\x34\n\x08\x43ommitTX\x12\r.types.TxList\x1a\x17.types.CommitResultList\"\x00\x12.\n\x08GetState\x12\x12.types.SingleBytes\x1a\x0c.types.State\"\x00\x12@\n\x10GetStateAndProof\x12\x15.types.AccountAndRoot\x1a\x13.types.AccountProof\"\x00\x12\x32\n\rCreateAccount\x12\x0f.types.Personal\x1a\x0e.types.Account\"\x00\x12\x31\n\x0bGetAccounts\x12\x0c.types.Empty\x1a\x12.types.AccountList\"\x00\x12\x30\n\x0bLockAccount\x12\x0f.types.Personal\x1a\x0e.types.Account\"\x00\x12\x32\n\rUnlockAccount\x12\x0f.types.Personal\x1a\x0e.types.Account\"\x00\x12\x36\n\rImportAccount\x12\x13.types.ImportFormat\x1a\x0e.types.Account\"\x00\x12\x36\n\rExportAccount\x12\x0f.types.Personal\x1a\x12.types.SingleBytes\"\x00\x12\x33\n\rQueryContract\x12\x0c.types.Query\x1a\x12.types.SingleBytes\"\x00\x12\x41\n\x12QueryContractState\x12\x11.types.StateQuery\x1a\x16.types.StateQueryProof\"\x00\x12\x31\n\x08GetPeers\x12\x12.types.PeersParams\x1a\x0f.types.PeerList\"\x00\x12\x30\n\x08GetVotes\x12\x11.types.VoteParams\x1a\x0f.types.VoteList\"\x00\x12\x42\n\x0fGetAccountVotes\x12\x15.types.AccountAddress\x1a\x16.types.AccountVoteInfo\"\x00\x12\x35\n\nGetStaking\x12\x15.types.AccountAddress\x1a\x0e.types.Staking\"\x00\x12-\n\x0bGetNameInfo\x12\x0b.types.Name\x1a\x0f.types.NameInfo\"\x00\x12\x36\n\x0fListEventStream\x12\x11.types.FilterInfo\x1a\x0c.types.Event\"\x00\x30\x01\x12\x33\n\nListEvents\x12\x11.types.FilterInfo\x1a\x10.types.EventList\"\x00\x12\x38\n\x10GetConsensusInfo\x12\x0c.types.Empty\x1a\x14.types.ConsensusInfo\"\x00\x42 Z\x1egithub.com/aergoio/aergo/typesb\x06proto3')
  ,
  dependencies=[blockchain__pb2.DESCRIPTOR,account__pb2.DESCRIPTOR,node__pb2.DESCRIPTOR,p2p__pb2.DESCRIPTOR,metric__pb2.DESCRIPTOR,])

_COMMITSTATUS = _descriptor.EnumDescriptor(
  name='CommitStatus',
  full_name='types.CommitStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TX_OK', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TX_NONCE_TOO_LOW', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TX_ALREADY_EXISTS', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TX_INVALID_HASH', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TX_INVALID_SIGN', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TX_INVALID_FORMAT', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TX_INSUFFICIENT_BALANCE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TX_HAS_SAME_NONCE', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TX_INTERNAL_ERROR', index=8, number=9,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2411,
  serialized_end=2621,
)
_sym_db.RegisterEnumDescriptor(_COMMITSTATUS)

CommitStatus = enum_type_wrapper.EnumTypeWrapper(_COMMITSTATUS)
_VERIFYSTATUS = _descriptor.EnumDescriptor(
  name='VerifyStatus',
  full_name='types.VerifyStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VERIFY_STATUS_OK', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERIFY_STATUS_SIGN_NOT_MATCH', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERIFY_STATUS_INVALID_HASH', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2623,
  serialized_end=2725,
)
_sym_db.RegisterEnumDescriptor(_VERIFYSTATUS)

VerifyStatus = enum_type_wrapper.EnumTypeWrapper(_VERIFYSTATUS)
TX_OK = 0
TX_NONCE_TOO_LOW = 1
TX_ALREADY_EXISTS = 2
TX_INVALID_HASH = 3
TX_INVALID_SIGN = 4
TX_INVALID_FORMAT = 5
TX_INSUFFICIENT_BALANCE = 6
TX_HAS_SAME_NONCE = 7
TX_INTERNAL_ERROR = 9
VERIFY_STATUS_OK = 0
VERIFY_STATUS_SIGN_NOT_MATCH = 1
VERIFY_STATUS_INVALID_HASH = 2



_BLOCKCHAINSTATUS = _descriptor.Descriptor(
  name='BlockchainStatus',
  full_name='types.BlockchainStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='best_block_hash', full_name='types.BlockchainStatus.best_block_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='best_height', full_name='types.BlockchainStatus.best_height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='consensus_info', full_name='types.BlockchainStatus.consensus_info', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='best_chain_id_hash', full_name='types.BlockchainStatus.best_chain_id_hash', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=206,
)


_CHAINID = _descriptor.Descriptor(
  name='ChainId',
  full_name='types.ChainId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='magic', full_name='types.ChainId.magic', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public', full_name='types.ChainId.public', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mainnet', full_name='types.ChainId.mainnet', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='consensus', full_name='types.ChainId.consensus', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=208,
  serialized_end=284,
)


_CHAININFO = _descriptor.Descriptor(
  name='ChainInfo',
  full_name='types.ChainInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='types.ChainInfo.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bpNumber', full_name='types.ChainInfo.bpNumber', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxblocksize', full_name='types.ChainInfo.maxblocksize', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxtokens', full_name='types.ChainInfo.maxtokens', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stakingminimum', full_name='types.ChainInfo.stakingminimum', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalstaking', full_name='types.ChainInfo.totalstaking', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gasprice', full_name='types.ChainInfo.gasprice', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nameprice', full_name='types.ChainInfo.nameprice', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=287,
  serialized_end=468,
)


_INPUT = _descriptor.Descriptor(
  name='Input',
  full_name='types.Input',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='types.Input.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address', full_name='types.Input.address', index=1,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='types.Input.value', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='script', full_name='types.Input.script', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=470,
  serialized_end=539,
)


_OUTPUT = _descriptor.Descriptor(
  name='Output',
  full_name='types.Output',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='types.Output.index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address', full_name='types.Output.address', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='types.Output.value', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='script', full_name='types.Output.script', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=541,
  serialized_end=612,
)


_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='types.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=614,
  serialized_end=621,
)


_SINGLEBYTES = _descriptor.Descriptor(
  name='SingleBytes',
  full_name='types.SingleBytes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='types.SingleBytes.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=623,
  serialized_end=651,
)


_ACCOUNTADDRESS = _descriptor.Descriptor(
  name='AccountAddress',
  full_name='types.AccountAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='types.AccountAddress.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=653,
  serialized_end=684,
)


_ACCOUNTANDROOT = _descriptor.Descriptor(
  name='AccountAndRoot',
  full_name='types.AccountAndRoot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Account', full_name='types.AccountAndRoot.Account', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Root', full_name='types.AccountAndRoot.Root', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Compressed', full_name='types.AccountAndRoot.Compressed', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=686,
  serialized_end=753,
)


_PEER = _descriptor.Descriptor(
  name='Peer',
  full_name='types.Peer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='types.Peer.address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bestblock', full_name='types.Peer.bestblock', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='types.Peer.state', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hidden', full_name='types.Peer.hidden', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lashCheck', full_name='types.Peer.lashCheck', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selfpeer', full_name='types.Peer.selfpeer', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=756,
  serialized_end=909,
)


_PEERLIST = _descriptor.Descriptor(
  name='PeerList',
  full_name='types.PeerList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='peers', full_name='types.PeerList.peers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=911,
  serialized_end=949,
)


_LISTPARAMS = _descriptor.Descriptor(
  name='ListParams',
  full_name='types.ListParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='types.ListParams.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='height', full_name='types.ListParams.height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='types.ListParams.size', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='types.ListParams.offset', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='asc', full_name='types.ListParams.asc', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=951,
  serialized_end=1036,
)


_PAGEPARAMS = _descriptor.Descriptor(
  name='PageParams',
  full_name='types.PageParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='types.PageParams.offset', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='types.PageParams.size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1038,
  serialized_end=1080,
)


_BLOCKBODYPAGED = _descriptor.Descriptor(
  name='BlockBodyPaged',
  full_name='types.BlockBodyPaged',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='types.BlockBodyPaged.total', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='types.BlockBodyPaged.offset', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='types.BlockBodyPaged.size', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='body', full_name='types.BlockBodyPaged.body', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1082,
  serialized_end=1175,
)


_BLOCKBODYPARAMS = _descriptor.Descriptor(
  name='BlockBodyParams',
  full_name='types.BlockBodyParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hashornumber', full_name='types.BlockBodyParams.hashornumber', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paging', full_name='types.BlockBodyParams.paging', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1177,
  serialized_end=1251,
)


_BLOCKHEADERLIST = _descriptor.Descriptor(
  name='BlockHeaderList',
  full_name='types.BlockHeaderList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blocks', full_name='types.BlockHeaderList.blocks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1253,
  serialized_end=1300,
)


_BLOCKMETADATA = _descriptor.Descriptor(
  name='BlockMetadata',
  full_name='types.BlockMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='types.BlockMetadata.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header', full_name='types.BlockMetadata.header', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='txcount', full_name='types.BlockMetadata.txcount', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1302,
  serialized_end=1384,
)


_BLOCKMETADATALIST = _descriptor.Descriptor(
  name='BlockMetadataList',
  full_name='types.BlockMetadataList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blocks', full_name='types.BlockMetadataList.blocks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1386,
  serialized_end=1443,
)


_COMMITRESULT = _descriptor.Descriptor(
  name='CommitResult',
  full_name='types.CommitResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='types.CommitResult.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='types.CommitResult.error', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='detail', full_name='types.CommitResult.detail', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1445,
  serialized_end=1525,
)


_COMMITRESULTLIST = _descriptor.Descriptor(
  name='CommitResultList',
  full_name='types.CommitResultList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='types.CommitResultList.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1527,
  serialized_end=1583,
)


_VERIFYRESULT = _descriptor.Descriptor(
  name='VerifyResult',
  full_name='types.VerifyResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx', full_name='types.VerifyResult.tx', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='types.VerifyResult.error', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1585,
  serialized_end=1658,
)


_PERSONAL = _descriptor.Descriptor(
  name='Personal',
  full_name='types.Personal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='passphrase', full_name='types.Personal.passphrase', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account', full_name='types.Personal.account', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1660,
  serialized_end=1723,
)


_IMPORTFORMAT = _descriptor.Descriptor(
  name='ImportFormat',
  full_name='types.ImportFormat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='wif', full_name='types.ImportFormat.wif', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldpass', full_name='types.ImportFormat.oldpass', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newpass', full_name='types.ImportFormat.newpass', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1725,
  serialized_end=1806,
)


_STAKING = _descriptor.Descriptor(
  name='Staking',
  full_name='types.Staking',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='types.Staking.amount', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='when', full_name='types.Staking.when', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1808,
  serialized_end=1847,
)


_VOTE = _descriptor.Descriptor(
  name='Vote',
  full_name='types.Vote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='candidate', full_name='types.Vote.candidate', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount', full_name='types.Vote.amount', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1849,
  serialized_end=1890,
)


_VOTEPARAMS = _descriptor.Descriptor(
  name='VoteParams',
  full_name='types.VoteParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='types.VoteParams.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='types.VoteParams.count', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1892,
  serialized_end=1931,
)


_ACCOUNTVOTEINFO = _descriptor.Descriptor(
  name='AccountVoteInfo',
  full_name='types.AccountVoteInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='staking', full_name='types.AccountVoteInfo.staking', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='voting', full_name='types.AccountVoteInfo.voting', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1933,
  serialized_end=2016,
)


_VOTEINFO = _descriptor.Descriptor(
  name='VoteInfo',
  full_name='types.VoteInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='types.VoteInfo.id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='candidates', full_name='types.VoteInfo.candidates', index=1,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2018,
  serialized_end=2060,
)


_VOTELIST = _descriptor.Descriptor(
  name='VoteList',
  full_name='types.VoteList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='votes', full_name='types.VoteList.votes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='types.VoteList.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2062,
  serialized_end=2112,
)


_NODEREQ = _descriptor.Descriptor(
  name='NodeReq',
  full_name='types.NodeReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeout', full_name='types.NodeReq.timeout', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='component', full_name='types.NodeReq.component', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2114,
  serialized_end=2159,
)


_NAME = _descriptor.Descriptor(
  name='Name',
  full_name='types.Name',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='types.Name.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2161,
  serialized_end=2181,
)


_NAMEINFO = _descriptor.Descriptor(
  name='NameInfo',
  full_name='types.NameInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='types.NameInfo.name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner', full_name='types.NameInfo.owner', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination', full_name='types.NameInfo.destination', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2183,
  serialized_end=2256,
)


_PEERSPARAMS = _descriptor.Descriptor(
  name='PeersParams',
  full_name='types.PeersParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='noHidden', full_name='types.PeersParams.noHidden', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='showSelf', full_name='types.PeersParams.showSelf', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2258,
  serialized_end=2307,
)


_EVENTLIST = _descriptor.Descriptor(
  name='EventList',
  full_name='types.EventList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='types.EventList.events', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2309,
  serialized_end=2350,
)


_CONSENSUSINFO = _descriptor.Descriptor(
  name='ConsensusInfo',
  full_name='types.ConsensusInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='types.ConsensusInfo.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info', full_name='types.ConsensusInfo.info', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bps', full_name='types.ConsensusInfo.bps', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2352,
  serialized_end=2408,
)

_CHAININFO.fields_by_name['id'].message_type = _CHAINID
_PEER.fields_by_name['address'].message_type = node__pb2._PEERADDRESS
_PEER.fields_by_name['bestblock'].message_type = p2p__pb2._NEWBLOCKNOTICE
_PEERLIST.fields_by_name['peers'].message_type = _PEER
_BLOCKBODYPAGED.fields_by_name['body'].message_type = blockchain__pb2._BLOCKBODY
_BLOCKBODYPARAMS.fields_by_name['paging'].message_type = _PAGEPARAMS
_BLOCKHEADERLIST.fields_by_name['blocks'].message_type = blockchain__pb2._BLOCK
_BLOCKMETADATA.fields_by_name['header'].message_type = blockchain__pb2._BLOCKHEADER
_BLOCKMETADATALIST.fields_by_name['blocks'].message_type = _BLOCKMETADATA
_COMMITRESULT.fields_by_name['error'].enum_type = _COMMITSTATUS
_COMMITRESULTLIST.fields_by_name['results'].message_type = _COMMITRESULT
_VERIFYRESULT.fields_by_name['tx'].message_type = blockchain__pb2._TX
_VERIFYRESULT.fields_by_name['error'].enum_type = _VERIFYSTATUS
_PERSONAL.fields_by_name['account'].message_type = account__pb2._ACCOUNT
_IMPORTFORMAT.fields_by_name['wif'].message_type = _SINGLEBYTES
_ACCOUNTVOTEINFO.fields_by_name['staking'].message_type = _STAKING
_ACCOUNTVOTEINFO.fields_by_name['voting'].message_type = _VOTEINFO
_VOTELIST.fields_by_name['votes'].message_type = _VOTE
_NAMEINFO.fields_by_name['name'].message_type = _NAME
_EVENTLIST.fields_by_name['events'].message_type = blockchain__pb2._EVENT
DESCRIPTOR.message_types_by_name['BlockchainStatus'] = _BLOCKCHAINSTATUS
DESCRIPTOR.message_types_by_name['ChainId'] = _CHAINID
DESCRIPTOR.message_types_by_name['ChainInfo'] = _CHAININFO
DESCRIPTOR.message_types_by_name['Input'] = _INPUT
DESCRIPTOR.message_types_by_name['Output'] = _OUTPUT
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
DESCRIPTOR.message_types_by_name['SingleBytes'] = _SINGLEBYTES
DESCRIPTOR.message_types_by_name['AccountAddress'] = _ACCOUNTADDRESS
DESCRIPTOR.message_types_by_name['AccountAndRoot'] = _ACCOUNTANDROOT
DESCRIPTOR.message_types_by_name['Peer'] = _PEER
DESCRIPTOR.message_types_by_name['PeerList'] = _PEERLIST
DESCRIPTOR.message_types_by_name['ListParams'] = _LISTPARAMS
DESCRIPTOR.message_types_by_name['PageParams'] = _PAGEPARAMS
DESCRIPTOR.message_types_by_name['BlockBodyPaged'] = _BLOCKBODYPAGED
DESCRIPTOR.message_types_by_name['BlockBodyParams'] = _BLOCKBODYPARAMS
DESCRIPTOR.message_types_by_name['BlockHeaderList'] = _BLOCKHEADERLIST
DESCRIPTOR.message_types_by_name['BlockMetadata'] = _BLOCKMETADATA
DESCRIPTOR.message_types_by_name['BlockMetadataList'] = _BLOCKMETADATALIST
DESCRIPTOR.message_types_by_name['CommitResult'] = _COMMITRESULT
DESCRIPTOR.message_types_by_name['CommitResultList'] = _COMMITRESULTLIST
DESCRIPTOR.message_types_by_name['VerifyResult'] = _VERIFYRESULT
DESCRIPTOR.message_types_by_name['Personal'] = _PERSONAL
DESCRIPTOR.message_types_by_name['ImportFormat'] = _IMPORTFORMAT
DESCRIPTOR.message_types_by_name['Staking'] = _STAKING
DESCRIPTOR.message_types_by_name['Vote'] = _VOTE
DESCRIPTOR.message_types_by_name['VoteParams'] = _VOTEPARAMS
DESCRIPTOR.message_types_by_name['AccountVoteInfo'] = _ACCOUNTVOTEINFO
DESCRIPTOR.message_types_by_name['VoteInfo'] = _VOTEINFO
DESCRIPTOR.message_types_by_name['VoteList'] = _VOTELIST
DESCRIPTOR.message_types_by_name['NodeReq'] = _NODEREQ
DESCRIPTOR.message_types_by_name['Name'] = _NAME
DESCRIPTOR.message_types_by_name['NameInfo'] = _NAMEINFO
DESCRIPTOR.message_types_by_name['PeersParams'] = _PEERSPARAMS
DESCRIPTOR.message_types_by_name['EventList'] = _EVENTLIST
DESCRIPTOR.message_types_by_name['ConsensusInfo'] = _CONSENSUSINFO
DESCRIPTOR.enum_types_by_name['CommitStatus'] = _COMMITSTATUS
DESCRIPTOR.enum_types_by_name['VerifyStatus'] = _VERIFYSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BlockchainStatus = _reflection.GeneratedProtocolMessageType('BlockchainStatus', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKCHAINSTATUS,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.BlockchainStatus)
  ))
_sym_db.RegisterMessage(BlockchainStatus)

ChainId = _reflection.GeneratedProtocolMessageType('ChainId', (_message.Message,), dict(
  DESCRIPTOR = _CHAINID,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.ChainId)
  ))
_sym_db.RegisterMessage(ChainId)

ChainInfo = _reflection.GeneratedProtocolMessageType('ChainInfo', (_message.Message,), dict(
  DESCRIPTOR = _CHAININFO,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.ChainInfo)
  ))
_sym_db.RegisterMessage(ChainInfo)

Input = _reflection.GeneratedProtocolMessageType('Input', (_message.Message,), dict(
  DESCRIPTOR = _INPUT,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.Input)
  ))
_sym_db.RegisterMessage(Input)

Output = _reflection.GeneratedProtocolMessageType('Output', (_message.Message,), dict(
  DESCRIPTOR = _OUTPUT,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.Output)
  ))
_sym_db.RegisterMessage(Output)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), dict(
  DESCRIPTOR = _EMPTY,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.Empty)
  ))
_sym_db.RegisterMessage(Empty)

SingleBytes = _reflection.GeneratedProtocolMessageType('SingleBytes', (_message.Message,), dict(
  DESCRIPTOR = _SINGLEBYTES,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.SingleBytes)
  ))
_sym_db.RegisterMessage(SingleBytes)

AccountAddress = _reflection.GeneratedProtocolMessageType('AccountAddress', (_message.Message,), dict(
  DESCRIPTOR = _ACCOUNTADDRESS,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.AccountAddress)
  ))
_sym_db.RegisterMessage(AccountAddress)

AccountAndRoot = _reflection.GeneratedProtocolMessageType('AccountAndRoot', (_message.Message,), dict(
  DESCRIPTOR = _ACCOUNTANDROOT,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.AccountAndRoot)
  ))
_sym_db.RegisterMessage(AccountAndRoot)

Peer = _reflection.GeneratedProtocolMessageType('Peer', (_message.Message,), dict(
  DESCRIPTOR = _PEER,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.Peer)
  ))
_sym_db.RegisterMessage(Peer)

PeerList = _reflection.GeneratedProtocolMessageType('PeerList', (_message.Message,), dict(
  DESCRIPTOR = _PEERLIST,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.PeerList)
  ))
_sym_db.RegisterMessage(PeerList)

ListParams = _reflection.GeneratedProtocolMessageType('ListParams', (_message.Message,), dict(
  DESCRIPTOR = _LISTPARAMS,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.ListParams)
  ))
_sym_db.RegisterMessage(ListParams)

PageParams = _reflection.GeneratedProtocolMessageType('PageParams', (_message.Message,), dict(
  DESCRIPTOR = _PAGEPARAMS,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.PageParams)
  ))
_sym_db.RegisterMessage(PageParams)

BlockBodyPaged = _reflection.GeneratedProtocolMessageType('BlockBodyPaged', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKBODYPAGED,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.BlockBodyPaged)
  ))
_sym_db.RegisterMessage(BlockBodyPaged)

BlockBodyParams = _reflection.GeneratedProtocolMessageType('BlockBodyParams', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKBODYPARAMS,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.BlockBodyParams)
  ))
_sym_db.RegisterMessage(BlockBodyParams)

BlockHeaderList = _reflection.GeneratedProtocolMessageType('BlockHeaderList', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKHEADERLIST,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.BlockHeaderList)
  ))
_sym_db.RegisterMessage(BlockHeaderList)

BlockMetadata = _reflection.GeneratedProtocolMessageType('BlockMetadata', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKMETADATA,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.BlockMetadata)
  ))
_sym_db.RegisterMessage(BlockMetadata)

BlockMetadataList = _reflection.GeneratedProtocolMessageType('BlockMetadataList', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKMETADATALIST,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.BlockMetadataList)
  ))
_sym_db.RegisterMessage(BlockMetadataList)

CommitResult = _reflection.GeneratedProtocolMessageType('CommitResult', (_message.Message,), dict(
  DESCRIPTOR = _COMMITRESULT,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.CommitResult)
  ))
_sym_db.RegisterMessage(CommitResult)

CommitResultList = _reflection.GeneratedProtocolMessageType('CommitResultList', (_message.Message,), dict(
  DESCRIPTOR = _COMMITRESULTLIST,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.CommitResultList)
  ))
_sym_db.RegisterMessage(CommitResultList)

VerifyResult = _reflection.GeneratedProtocolMessageType('VerifyResult', (_message.Message,), dict(
  DESCRIPTOR = _VERIFYRESULT,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.VerifyResult)
  ))
_sym_db.RegisterMessage(VerifyResult)

Personal = _reflection.GeneratedProtocolMessageType('Personal', (_message.Message,), dict(
  DESCRIPTOR = _PERSONAL,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.Personal)
  ))
_sym_db.RegisterMessage(Personal)

ImportFormat = _reflection.GeneratedProtocolMessageType('ImportFormat', (_message.Message,), dict(
  DESCRIPTOR = _IMPORTFORMAT,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.ImportFormat)
  ))
_sym_db.RegisterMessage(ImportFormat)

Staking = _reflection.GeneratedProtocolMessageType('Staking', (_message.Message,), dict(
  DESCRIPTOR = _STAKING,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.Staking)
  ))
_sym_db.RegisterMessage(Staking)

Vote = _reflection.GeneratedProtocolMessageType('Vote', (_message.Message,), dict(
  DESCRIPTOR = _VOTE,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.Vote)
  ))
_sym_db.RegisterMessage(Vote)

VoteParams = _reflection.GeneratedProtocolMessageType('VoteParams', (_message.Message,), dict(
  DESCRIPTOR = _VOTEPARAMS,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.VoteParams)
  ))
_sym_db.RegisterMessage(VoteParams)

AccountVoteInfo = _reflection.GeneratedProtocolMessageType('AccountVoteInfo', (_message.Message,), dict(
  DESCRIPTOR = _ACCOUNTVOTEINFO,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.AccountVoteInfo)
  ))
_sym_db.RegisterMessage(AccountVoteInfo)

VoteInfo = _reflection.GeneratedProtocolMessageType('VoteInfo', (_message.Message,), dict(
  DESCRIPTOR = _VOTEINFO,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.VoteInfo)
  ))
_sym_db.RegisterMessage(VoteInfo)

VoteList = _reflection.GeneratedProtocolMessageType('VoteList', (_message.Message,), dict(
  DESCRIPTOR = _VOTELIST,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.VoteList)
  ))
_sym_db.RegisterMessage(VoteList)

NodeReq = _reflection.GeneratedProtocolMessageType('NodeReq', (_message.Message,), dict(
  DESCRIPTOR = _NODEREQ,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.NodeReq)
  ))
_sym_db.RegisterMessage(NodeReq)

Name = _reflection.GeneratedProtocolMessageType('Name', (_message.Message,), dict(
  DESCRIPTOR = _NAME,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.Name)
  ))
_sym_db.RegisterMessage(Name)

NameInfo = _reflection.GeneratedProtocolMessageType('NameInfo', (_message.Message,), dict(
  DESCRIPTOR = _NAMEINFO,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.NameInfo)
  ))
_sym_db.RegisterMessage(NameInfo)

PeersParams = _reflection.GeneratedProtocolMessageType('PeersParams', (_message.Message,), dict(
  DESCRIPTOR = _PEERSPARAMS,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.PeersParams)
  ))
_sym_db.RegisterMessage(PeersParams)

EventList = _reflection.GeneratedProtocolMessageType('EventList', (_message.Message,), dict(
  DESCRIPTOR = _EVENTLIST,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.EventList)
  ))
_sym_db.RegisterMessage(EventList)

ConsensusInfo = _reflection.GeneratedProtocolMessageType('ConsensusInfo', (_message.Message,), dict(
  DESCRIPTOR = _CONSENSUSINFO,
  __module__ = 'rpc_pb2'
  # @@protoc_insertion_point(class_scope:types.ConsensusInfo)
  ))
_sym_db.RegisterMessage(ConsensusInfo)


DESCRIPTOR._options = None

_AERGORPCSERVICE = _descriptor.ServiceDescriptor(
  name='AergoRPCService',
  full_name='types.AergoRPCService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2728,
  serialized_end=4739,
  methods=[
  _descriptor.MethodDescriptor(
    name='NodeState',
    full_name='types.AergoRPCService.NodeState',
    index=0,
    containing_service=None,
    input_type=_NODEREQ,
    output_type=_SINGLEBYTES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Metric',
    full_name='types.AergoRPCService.Metric',
    index=1,
    containing_service=None,
    input_type=metric__pb2._METRICSREQUEST,
    output_type=metric__pb2._METRICS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Blockchain',
    full_name='types.AergoRPCService.Blockchain',
    index=2,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_BLOCKCHAINSTATUS,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetChainInfo',
    full_name='types.AergoRPCService.GetChainInfo',
    index=3,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_CHAININFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListBlockHeaders',
    full_name='types.AergoRPCService.ListBlockHeaders',
    index=4,
    containing_service=None,
    input_type=_LISTPARAMS,
    output_type=_BLOCKHEADERLIST,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListBlockMetadata',
    full_name='types.AergoRPCService.ListBlockMetadata',
    index=5,
    containing_service=None,
    input_type=_LISTPARAMS,
    output_type=_BLOCKMETADATALIST,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListBlockStream',
    full_name='types.AergoRPCService.ListBlockStream',
    index=6,
    containing_service=None,
    input_type=_EMPTY,
    output_type=blockchain__pb2._BLOCK,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListBlockMetadataStream',
    full_name='types.AergoRPCService.ListBlockMetadataStream',
    index=7,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_BLOCKMETADATA,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetBlock',
    full_name='types.AergoRPCService.GetBlock',
    index=8,
    containing_service=None,
    input_type=_SINGLEBYTES,
    output_type=blockchain__pb2._BLOCK,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetBlockMetadata',
    full_name='types.AergoRPCService.GetBlockMetadata',
    index=9,
    containing_service=None,
    input_type=_SINGLEBYTES,
    output_type=_BLOCKMETADATA,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetBlockBody',
    full_name='types.AergoRPCService.GetBlockBody',
    index=10,
    containing_service=None,
    input_type=_BLOCKBODYPARAMS,
    output_type=_BLOCKBODYPAGED,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetTX',
    full_name='types.AergoRPCService.GetTX',
    index=11,
    containing_service=None,
    input_type=_SINGLEBYTES,
    output_type=blockchain__pb2._TX,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetBlockTX',
    full_name='types.AergoRPCService.GetBlockTX',
    index=12,
    containing_service=None,
    input_type=_SINGLEBYTES,
    output_type=blockchain__pb2._TXINBLOCK,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetReceipt',
    full_name='types.AergoRPCService.GetReceipt',
    index=13,
    containing_service=None,
    input_type=_SINGLEBYTES,
    output_type=blockchain__pb2._RECEIPT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetABI',
    full_name='types.AergoRPCService.GetABI',
    index=14,
    containing_service=None,
    input_type=_SINGLEBYTES,
    output_type=blockchain__pb2._ABI,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SendTX',
    full_name='types.AergoRPCService.SendTX',
    index=15,
    containing_service=None,
    input_type=blockchain__pb2._TX,
    output_type=_COMMITRESULT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SignTX',
    full_name='types.AergoRPCService.SignTX',
    index=16,
    containing_service=None,
    input_type=blockchain__pb2._TX,
    output_type=blockchain__pb2._TX,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='VerifyTX',
    full_name='types.AergoRPCService.VerifyTX',
    index=17,
    containing_service=None,
    input_type=blockchain__pb2._TX,
    output_type=_VERIFYRESULT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CommitTX',
    full_name='types.AergoRPCService.CommitTX',
    index=18,
    containing_service=None,
    input_type=blockchain__pb2._TXLIST,
    output_type=_COMMITRESULTLIST,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetState',
    full_name='types.AergoRPCService.GetState',
    index=19,
    containing_service=None,
    input_type=_SINGLEBYTES,
    output_type=blockchain__pb2._STATE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetStateAndProof',
    full_name='types.AergoRPCService.GetStateAndProof',
    index=20,
    containing_service=None,
    input_type=_ACCOUNTANDROOT,
    output_type=blockchain__pb2._ACCOUNTPROOF,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CreateAccount',
    full_name='types.AergoRPCService.CreateAccount',
    index=21,
    containing_service=None,
    input_type=_PERSONAL,
    output_type=account__pb2._ACCOUNT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAccounts',
    full_name='types.AergoRPCService.GetAccounts',
    index=22,
    containing_service=None,
    input_type=_EMPTY,
    output_type=account__pb2._ACCOUNTLIST,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='LockAccount',
    full_name='types.AergoRPCService.LockAccount',
    index=23,
    containing_service=None,
    input_type=_PERSONAL,
    output_type=account__pb2._ACCOUNT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UnlockAccount',
    full_name='types.AergoRPCService.UnlockAccount',
    index=24,
    containing_service=None,
    input_type=_PERSONAL,
    output_type=account__pb2._ACCOUNT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ImportAccount',
    full_name='types.AergoRPCService.ImportAccount',
    index=25,
    containing_service=None,
    input_type=_IMPORTFORMAT,
    output_type=account__pb2._ACCOUNT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ExportAccount',
    full_name='types.AergoRPCService.ExportAccount',
    index=26,
    containing_service=None,
    input_type=_PERSONAL,
    output_type=_SINGLEBYTES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='QueryContract',
    full_name='types.AergoRPCService.QueryContract',
    index=27,
    containing_service=None,
    input_type=blockchain__pb2._QUERY,
    output_type=_SINGLEBYTES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='QueryContractState',
    full_name='types.AergoRPCService.QueryContractState',
    index=28,
    containing_service=None,
    input_type=blockchain__pb2._STATEQUERY,
    output_type=blockchain__pb2._STATEQUERYPROOF,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetPeers',
    full_name='types.AergoRPCService.GetPeers',
    index=29,
    containing_service=None,
    input_type=_PEERSPARAMS,
    output_type=_PEERLIST,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetVotes',
    full_name='types.AergoRPCService.GetVotes',
    index=30,
    containing_service=None,
    input_type=_VOTEPARAMS,
    output_type=_VOTELIST,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAccountVotes',
    full_name='types.AergoRPCService.GetAccountVotes',
    index=31,
    containing_service=None,
    input_type=_ACCOUNTADDRESS,
    output_type=_ACCOUNTVOTEINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetStaking',
    full_name='types.AergoRPCService.GetStaking',
    index=32,
    containing_service=None,
    input_type=_ACCOUNTADDRESS,
    output_type=_STAKING,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetNameInfo',
    full_name='types.AergoRPCService.GetNameInfo',
    index=33,
    containing_service=None,
    input_type=_NAME,
    output_type=_NAMEINFO,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListEventStream',
    full_name='types.AergoRPCService.ListEventStream',
    index=34,
    containing_service=None,
    input_type=blockchain__pb2._FILTERINFO,
    output_type=blockchain__pb2._EVENT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListEvents',
    full_name='types.AergoRPCService.ListEvents',
    index=35,
    containing_service=None,
    input_type=blockchain__pb2._FILTERINFO,
    output_type=_EVENTLIST,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetConsensusInfo',
    full_name='types.AergoRPCService.GetConsensusInfo',
    index=36,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_CONSENSUSINFO,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_AERGORPCSERVICE)

DESCRIPTOR.services_by_name['AergoRPCService'] = _AERGORPCSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-

"""Top-level package for herapy."""

__all__ = ["errors", "utils"]

from .aergo import Aergo
from .account import Account
from .obj.aer import Aer
from .obj.aergo_conf import AergoConfig, AERGO_DEFAULT_CONF
from .obj.transaction import Transaction
from .obj.block import Block
from .obj.peer import Peer
from .status.commit_status import CommitStatus
from .status.tx_result_status import TxResultStatus




# -*- coding: utf-8 -*-


class CallInfo():
    """ CallInfo is used to store contract call/query arguments for json serialization."""
    def __init__(self, name, args):
        self.name = name
        self.args = args



import sys
import traceback
import json

import aergo.herapy as herapy

from aergo.herapy.utils.converter import convert_bytes_to_hex_str, \
                                         convert_bytes_to_int_str, get_hash


def eprint(*args, **kwargs):
    print(*args, file=sys.stderr, **kwargs)
    print(*args, **kwargs)


def run():
    try:
        aergo = herapy.Aergo()

        print("------ Connect AERGO -----------")
        #aergo.connect('localhost:7845')
        #aergo.connect('ec2-35-178-173-137.eu-west-2.compute.amazonaws.com:7845')
        aergo.connect('13.209.254.56:7845')

        print("------ Get Blockchain Info -----------")
        blockchain_info = aergo.get_chain_info()
        print("Blockchain Info: {}".format(str(blockchain_info)))
        blockchain_info = aergo.get_chain_info(with_consensus_info=False)
        print("Blockchain Info: {}".format(str(blockchain_info)))

        print("------ Get Consensus Info -----------")
        consensus_info = aergo.get_consensus_info()
        print("Consensus Info: {}".format(str(consensus_info)))

        print("------ Get Blockchain Status -----------")
        blockchain_status = aergo.get_status()
        print("Blockchain Status: {}".format(str(blockchain_status)))
        print("Best Block Hash      = {}".format(str(blockchain_status.best_block_hash)))
        print("Best Block Height    = {}".format(blockchain_status.best_block_height))
        print("Best Chain ID Hash         = {}".format(blockchain_status.best_chain_id_hash))
        print("base58(Best Chain ID Hash) = {}".format(blockchain_status.best_chain_id_hash_b58))
        consensus_info = blockchain_status.consensus_info
        print("Consensus Info       = {}".format(consensus_info))
        print("Consensus Info: type     = {}".format(consensus_info.type))
        print("Consensus Info: status   = {}".format(consensus_info.status))
        print("Consensus Info: LIB hash = {}".format(consensus_info.lib_hash))
        print("Consensus Info: LIB no   = {}".format(consensus_info.lib_no))

        best_block_hash, best_block_height = aergo.get_blockchain_status()
        print("Best Block Hash      = {}".format(best_block_hash))
        print("str(Best Block Hash)     = {}".format(str(best_block_hash)))
        print("bytes(Best Block Hash)   = {}".format(bytes(best_block_hash)))
        print("int(Best Block Hash)     = {}"
              .format(convert_bytes_to_int_str(bytes(best_block_hash))))
        print("hex(Best Block Hash)     = {}"
              .format(convert_bytes_to_hex_str(bytes(best_block_hash))))
        print("Best Block Height    = {}".format(best_block_height))

        print("------ Get Block Status -----------")
        block = aergo.get_block(best_block_hash)
        print("Block Chain ID Hash         = ", block.chain_id_hash)
        print("base58(Block Chain ID Hash) = ", block.chain_id_hash_b58)
        print("Block Hash = ", block.hash)
        print("  Height = ", block.height)
        print("  Timestamp = ", block.timestamp)
        print("  Blocks Root Hash = ", block.blocks_root_hash)
        print("  Txs Root Hash = ", block.txs_root_hash)
        print("  Confirm = ", block.confirms)
        print("  Pub Key = ", block.public_key)
        print("  Sign = ", block.sign)
        print("  previous block hash =\n{}".format(block.prev))
        print("  Txs = ", block.tx_list)
        print(json.dumps(block.json(), indent=2))

        block = aergo.get_block(block_height=best_block_height)
        print(block)
        print("Block Hash = ", block.hash)
        print("  Height = ", block.height)
        print("  Timestamp = ", block.timestamp)
        print("  Blocks Root Hash = ", block.blocks_root_hash)
        print("  Txs Root Hash = ", block.txs_root_hash)
        print("  Confirm = ", block.confirms)
        print("  Pub Key = ", block.public_key)
        print("  Sign = ", block.sign)
        print("  previous block hash =\n{}".format(block.prev))
        print("  Txs = ", block.tx_list)

        print("------ Get Peers -----------")
        # definition of peer needs to describe.
        peers = aergo.get_peers()
        for p in peers:
            print(p)

        print("------ Get Node State -----------")
        node_state = aergo.get_node_state()
        print(node_state)
        node_state_fmt_txt = json.dumps(node_state, indent=2, sort_keys=True)
        print(node_state_fmt_txt)

        print("------ Disconnect AERGO -----------")
        aergo.disconnect()
    except Exception as e:
        eprint(e)
        traceback.print_exception(*sys.exc_info())


if __name__ == '__main__':
    run()



import sys
import traceback
import time

import aergo.herapy as herapy
from aergo.herapy.obj.sc_state import SCStateVar


def eprint(*args, **kwargs):
    print(*args, file=sys.stderr, **kwargs)
    print(*args, **kwargs)


def run():
    print("------ Payload -----------")
    """
        -- Define global variables.
        state.var {
            a = state.value(),
            b = state.array(3),
            c = state.map(),
        }

        function constructor(name)
            a:set("a_" .. name)
            b[1] = "b_" .. name
            c["init"] = "c_" .. name
        end

        function set_name(key, name)
            if key == "a" then
                a:set(name)
            elseif key == "b" then
                b[2] = name
            else
                c['name'] = name
            end
        end

        function get_name(key)
            if key == "a" then
                return a:get()
            elseif key == "b" then
                return b[2]
            else
                return c['name']
            end
        end

        function say_hello()
            a:set("hello A")
            b[3] = "hello B"
            c["hello"] = "hello C"
        end

        abi.register(set_name, get_name, say_hello)
    """
    payload_str = "2Jzi8odjCSuGxVM4TVcUt8S5zKHcoZdqrzQ7vfPvSMhTez6hDzd4ZcpQr18roCbaDBtdsWRBHQV1eGkzegNTPrshcHvXf1sSmP62YCNSvYzBDbhv5qkDjhK3qAE2x1MdUKUtJjMZ1Y9ZXQDFSwjzAkYomv7SnLr4fDfYEGdhULtc3LWsiafswkJXu1c4wiVg4hfQDgXepBR5o7qoSYdN7tKtRLP9X3gkqJX1Y8FauETxzewMWZWhDAJYbEL5PY8C1gtDzf9jG7446xHWEj2AMyu2KN7dnGQzUoFshYFE9CtbzRRGUJqUdx9EPbqC3VvqrqsJDYsn31UeUGfAfgVMxb2uig8cAqSVb8AKM7TVqZfXWcQdcvEgYnDb9ujSpyiazQpxYAtchenDeyU9Mud4yNNNQHW1zsJcZpgPiHdDRbZDwmiiJ4h6bA3fBwCujNqEkTHL5H8RgaFZ65WbthtpKV5FiLfu22YCaL8BP7YLQd2zKDQZdAVgtWndqUyKEJ9tAvcKd2ZoM7KLsusGvFkoCerqhRktVAvyjrsUh9ttSY6bcCX3F8gz7nfzuFGQ9UggNBtBCSMxLfWARugVrifBL8D2kA2BqA9Q67Vk4fTss5iHsVPunaEQaJCBvBWrda2fn6tKoDy5vM27zaN81tmMisR76r9M3SfjGZbWcaFDRqN8SFmnP4t9L9EcVgWaquKkGzchqQY5kvTZSphJkvBa9HoEjc8JQaMxuXj2mzwpzmcRM7EXMJSVRTBKbhekH1zNus7QWeq2G8iLP4jwKjcLT9cRj9MRCj5Tkfs4tMKQrVo72LN3JBTc5rNBGgHRE9uHb39bfNqpzvURPAxP7AREyJhVuzjaNmEbYo5Zw1b73TnKFPYTRa4SpDFajopoRa8KpBU6m6XhRpRNWW6eYWahF9gnYX2qYjeEzz27a7xuSEwW2Bx8LqoQzSVpkJ1qoVYLzWqCDPDzEPS295vnbrABnL6Q3vhaAG4nGqtnkftkWVSakESKRz5YcedQe2Y8t51J2hPS8k3t7VGQoYUxvdMSwyYcKBiRXMjCPxZ7QUKTd42Snwhmcy5s6PMbzdxGJT1EvUL2hJ9wMfVqkFkJoSJ2UXmjJE31J7KBCmpUiicAopDfrYAzgKnRHiTyPRmi3oFJe1KGBg9iuNJKQsEHvykySnuooyZhGoXChSMV4HMVBBr9LHajQE23TEJoQSSGihUHb38wtgpHm4r1APi95npgPcwJnRde7CyHJw8MAd7sUiGq"
    payload = herapy.utils.decode_address(payload_str)

    try:
        aergo = herapy.Aergo()

        print("------ Connect AERGO -----------")
        aergo.connect('localhost:7845')

        print("------ Set Sender Account -----------")
        sender_private_key = "6hbRWgddqcg2ZHE5NipM1xgwBDAKqLnCKhGvADWrWE18xAbX8sW"
        sender_account = aergo.new_account(private_key=sender_private_key)
        print("  > Sender Address: {}".format(sender_account.address))
        print(herapy.utils.convert_bytes_to_int_str(bytes(sender_account.address)))

        aergo.get_account()
        print("    > account state of Sender")
        print("      - balance        = {}".format(sender_account.balance))
        print("      - nonce          = {}".format(sender_account.nonce))
        print("      - code hash      = {}".format(sender_account.code_hash))
        print("      - storage root   = {}".format(sender_account.storage_root))

        print("------ Deploy SC -----------")
        tx, result = aergo.deploy_sc(amount=0, payload=payload, args=1234)
        print("  > TX: {}".format(tx.tx_hash))
        print("{}".format(herapy.utils.convert_tx_to_json(tx)))
        if result.status != herapy.CommitStatus.TX_OK:
            eprint("    > ERROR[{0}]: {1}".format(result.status, result.detail))
            aergo.disconnect()
            return
        else:
            print("    > result[{0}] : {1}".format(result.tx_id, result.status.name))
            print(herapy.utils.convert_bytes_to_int_str(bytes(tx.tx_hash)))

        time.sleep(3)

        print("------ Check deployment of SC -----------")
        print("  > TX: {}".format(tx.tx_hash))
        result = aergo.get_tx_result(tx.tx_hash)
        if result.status != herapy.TxResultStatus.CREATED:
            eprint("  > ERROR[{0}]:{1}: {2}".format(
                result.contract_address, result.status, result.detail))
            aergo.disconnect()
            return

        sc_address = result.contract_address
        print("  > SC Address: {}".format(sc_address))

        print("------ Query SC State Var with Proof -----------")
        best_block_hash, best_block_height = aergo.get_blockchain_status()
        block = aergo.get_block(best_block_hash)
        root = block.blocks_root_hash
        sc_state = aergo.query_sc_state(sc_address, ["_sv_a"], root=root)
        sc_root = sc_state.account.state_proof.state.storageRoot
        print("Variable Proof: {}".format(sc_state.var_proofs.verify_var_proof(root=sc_root,
                                                                               var_proof=sc_state.var_proofs[0])))
        print("Variables Proof: {}".format(sc_state.var_proofs.verify_proof(root=sc_root)))
        print("Total Proof: {}".format(sc_state.verify_proof(root)))

        sc_state = aergo.query_sc_state(sc_address, ["_sv_a", "_sv_b-1", "_sv_c-init"], root=root)
        print("Proof: {}".format(sc_state.verify_proof(root)))
        for i, vp in enumerate(sc_state.var_proofs):
            print("[{0}] Variable Proof: {1}".format(i, sc_state.var_proofs.verify_var_proof(root=sc_root,
                                                                                             var_proof=vp)))
            print("  var_proof.key          = {}".format(vp.key))
            print("  var_proof.value        = {}".format(vp.value))
            print("  var_proof.inclusion    = {}".format(vp.inclusion))
            print("  var_proof.proof_key    = {}".format(vp.proofKey))
            print("  var_proof.proof_value  = {}".format(vp.proofVal))
            print("  var_proof.bitmap       = {}".format(vp.bitmap))
            print("  var_proof.height       = {}".format(vp.height))

        sc_var_a = SCStateVar(var_name="a")
        sc_var_b = SCStateVar(var_name="b", array_index=1)
        sc_var_c = SCStateVar(var_name="c", map_key='init')
        sc_state = aergo.query_sc_state(sc_address, [sc_var_a, sc_var_b, sc_var_c], root=root, compressed=False)
        print("Proof: {}".format(sc_state.verify_proof(root)))

        sc_state = aergo.query_sc_state(sc_address, ['not', 'included', 'var'], root=root)
        for i, vp in enumerate(sc_state.var_proofs):
            print("var[{}]".format(i))
            print("  key: {}".format(vp.key))
            print("  inclusion? {}".format(vp.inclusion))
        print("not inclusion? Proof = {}".format(sc_state.verify_proof(root)))

        sc_state = aergo.query_sc_state(sc_address, ['not', 'included', 'var'], root=root, compressed=False)
        for i, vp in enumerate(sc_state.var_proofs):
            print("var[{}]".format(i))
            print("  key: {}".format(vp.key))
            print("  inclusion? {}".format(vp.inclusion))
        print("not inclusion? Proof = {}".format(sc_state.verify_proof(root)))

        address = "AmMejL8z3wW2doksBzzMiWM2xTb6WtZniLkLyxwqWKiLJKK8Yvqd"
        sc_state = aergo.query_sc_state(address, ["_sv_a"], root=root)
        sc_root = sc_state.account.state_proof.state.storageRoot
        print("Number of Variable Proofs = {}".format(len(sc_state.var_proofs)))
        print("Variables Proof: {}".format(sc_state.var_proofs.verify_proof(root=sc_root)))
        print("Total Proof: {}".format(sc_state.verify_proof(root)))

        print("------ Disconnect AERGO -----------")
        aergo.disconnect()
    except Exception as e:
        eprint(e)
        traceback.print_exception(*sys.exc_info())


if __name__ == '__main__':
    run()



import sys
import traceback

import aergo.herapy as herapy


def eprint(*args, **kwargs):
    print(*args, file=sys.stderr, **kwargs)
    print(*args, **kwargs)


def run():
    try:
        aergo = herapy.Aergo()

        print("------ Connect AERGO -----------")
        aergo.connect('localhost:7845')

        address = "AmPwBMCcYbqyetVmAupjtzR8GgnTAVduZAVE9SnJPzjhWEmhjSef"

        print("------ Fund a second account to pass test in testmode -------")
        sender_private_key = "6hbRWgddqcg2ZHE5NipM1xgwBDAKqLnCKhGvADWrWE18xAbX8sW"
        aergo.new_account(private_key=sender_private_key)
        simple_tx, result = aergo.send_payload(to_address=address,
                                               amount=10, payload=None,
                                               retry_nonce=3)
        if result.status != herapy.CommitStatus.TX_OK:
            eprint("    > ERROR[{0}]: {1}".format(result.status, result.detail))
        else:
            print("    > result[{0}] : {1}".format(result.tx_id,
                                                   result.status.name))

        print("------ Get Account State -----------")
        best_block_hash, best_block_height = aergo.get_blockchain_status()
        block = aergo.get_block(best_block_hash)
        root = block.blocks_root_hash
        account = aergo.get_account(address=address, proof=True, root=root)
        account2 = aergo.get_account(address=address, proof=True,
                                     compressed=False, root=root)

        print("account = {}".format(account))
        print("account.balance = {}".format(account.balance.aergo))
        print("account2 = {}".format(account2))
        print("account2.balance = {}".format(account2.balance.aergo))

        print("------ Verify inclusion proof -----------")
        print("valid inclusion proof compressed: ",
              account.verify_proof(root))
        print("valid inclusion proof: ", account2.verify_proof(root))

        print("------ Verify Non inclusion proof -----------")
        address = "AmMejL8z3wW2doksBzzMiWM2xTb6WtZniLkLyxwqWKiLJKK8Yvqd"
        account = aergo.get_account(address=address, proof=True, root=root)
        account2 = aergo.get_account(address=address, proof=True,
                                     compressed=False, root=root)
        print(account)
        print(account2)
        print("valid exclusion proof compressed: ",
              account.verify_proof(root))
        print("valid exclusion proof: ", account2.verify_proof(root))

        print("------ Disconnect AERGO -----------")
        aergo.disconnect()
    except Exception:
        traceback.print_exception(*sys.exc_info())


if __name__ == '__main__':
    run()




########################################
# !!!DO NOT MODIFY THIS FILE DIRECTLY!!!
########################################
#
# This file is generated by 'generate_aergo_conf.py'.
#
AERGO_CONF_KEYS = {
    "base": ["datadir", "dbtype", "enableprofile", "profileport", "enabletestmode", "usetestnet", "personal", "authdir", ],
    "rpc": ["netserviceaddr", "netserviceport", "netservicetrace", "nstls", "nscert", "nskey", "nsallowcors", ],
    "p2p": ["netprotocoladdr", "netprotocolport", "npbindaddr", "npbindport", "nptls", "npcert", "npkey", "npaddpeers", "nphiddenpeers", "npdiscoverpeers", "npmaxpeers", "nppeerpool", "npexposeself", "npusepolaris", "npaddpolarises", "logfullpeerid", ],
    "polaris": ["allowprivate", "genesisfile", ],
    "blockchain": ["maxblocksize", "coinbaseaccount", "maxanchorcount", "verifiercount", "forceresetheight", "fixedtxfee", ],
    "mempool": ["showmetrics", "enablefadeout", "fadeoutperiod", "verifiers", "dumpfilepath", ],
    "consensus": ["enablebp", "blockinterval", "raft", ],
    "monitor": ["protocol", "endpoint", ],
    "account": ["unlocktimeout", ],
}

AERGO_DEFAULT_CONF = {
    "datadir": "${AERGO_HOME}/data",
    "dbtype": "badgerdb",
    "enableprofile": False,
    "profileport": 6060,
    "enabletestmode": False,
    "personal": True,
    "authdir": "${AERGO_HOME}/auth",
    "rpc": {
        "netserviceaddr": "127.0.0.1",
        "netserviceport": 7845,
        "netservicetrace": False,
        "nstls": False,
        "nskey": "",
    },
    "p2p": {
        "netprotocoladdr": "",
        "netprotocolport": 7846,
        "npbindaddr": "",
        "npbindport": -1,
        "nptls": False,
        "npcert": "",
        "npkey": "",
        "npaddpeers": [],
        "npdiscoverpeers": True,
        "npmaxpeers": 100,
        "nppeerpool": 100,
        "npexposeself": True,
        "npusepolaris": True,
        "npaddpolarises": [],
    },
    "polaris": {
        "allowprivate": False,
        "genesisfile": "",
    },
    "blockchain": {
        "maxblocksize": 1048576,
        "coinbaseaccount": "",
        "maxanchorcount": 20,
        "forceresetheight": 0,
        "fixedtxfee": "0",
    },
    "mempool": {
        "showmetrics": False,
        "enablefadeout": False,
        "fadeoutperiod": 12,
        "dumpfilepath": "${AERGO_HOME}/mempool.dump",
    },
    "consensus": {
        "enablebp": False,
        "blockinterval": 1,
    },
    "monitor": {
        "protocol": "",
        "endpoint": "",
    },
    "account": {
        "unlocktimeout": 60,
    },
}


class AergoConfig:
    def __init__(self):
        self.__conf = dict(AERGO_DEFAULT_CONF)
        self.__conf['rpc'] = dict(AERGO_DEFAULT_CONF['rpc'])
        self.__conf['p2p'] = dict(AERGO_DEFAULT_CONF['p2p'])
        self.__conf['polaris'] = dict(AERGO_DEFAULT_CONF['polaris'])
        self.__conf['blockchain'] = dict(AERGO_DEFAULT_CONF['blockchain'])
        self.__conf['mempool'] = dict(AERGO_DEFAULT_CONF['mempool'])
        self.__conf['consensus'] = dict(AERGO_DEFAULT_CONF['consensus'])
        self.__conf['monitor'] = dict(AERGO_DEFAULT_CONF['monitor'])
        self.__conf['account'] = dict(AERGO_DEFAULT_CONF['account'])

    def add_conf(self, k, v, c="base"):
        exist = False
        for key in AERGO_CONF_KEYS[c]:
            if key == k:
                exist = True
                break

        if not exist:
            raise KeyError("cannot find a configuration key: " + k)

        if c == "base":
            self.__conf[k] = v
        else:
            self.__conf[c][k] = v

    @property
    def conf(self):
        return self.__conf

    @property
    def datadir(self):
        return str(self.__conf['datadir'])

    @datadir.setter
    def datadir(self, v):
        if not isinstance(v, str):
            raise TypeError('input value should be a string type')
        self.__conf['datadir'] = v

    @property
    def dbtype(self):
        return str(self.__conf['dbtype'])

    @dbtype.setter
    def dbtype(self, v):
        if not isinstance(v, str):
            raise TypeError('input value should be a string type')
        self.__conf['dbtype'] = v

    @property
    def enableprofile(self):
        return bool(self.__conf['enableprofile'])

    @enableprofile.setter
    def enableprofile(self, v):
        if not isinstance(v, bool):
            raise TypeError('input value should be a boolean type')
        self.__conf['enableprofile'] = v

    @property
    def profileport(self):
        return int(self.__conf['profileport'])

    @profileport.setter
    def profileport(self, v):
        if not isinstance(v, int):
            raise TypeError('input value should be an integer type')
        self.__conf['profileport'] = v

    @property
    def enabletestmode(self):
        return bool(self.__conf['enabletestmode'])

    @enabletestmode.setter
    def enabletestmode(self, v):
        if not isinstance(v, bool):
            raise TypeError('input value should be a boolean type')
        self.__conf['enabletestmode'] = v

    @property
    def usetestnet(self):
        return bool(self.__conf['usetestnet'])

    @usetestnet.setter
    def usetestnet(self, v):
        if not isinstance(v, bool):
            raise TypeError('input value should be a boolean type')
        self.__conf['usetestnet'] = v

    @property
    def personal(self):
        return bool(self.__conf['personal'])

    @personal.setter
    def personal(self, v):
        if not isinstance(v, bool):
            raise TypeError('input value should be a boolean type')
        self.__conf['personal'] = v

    @property
    def authdir(self):
        return str(self.__conf['authdir'])

    @authdir.setter
    def authdir(self, v):
        if not isinstance(v, str):
            raise TypeError('input value should be a string type')
        self.__conf['authdir'] = v

    @property
    def rpc(self):
        return self.__conf['rpc']

    @property
    def rpc_netserviceaddr(self):
        return str(self.__conf['rpc']['netserviceaddr'])

    @rpc_netserviceaddr.setter
    def rpc_netserviceaddr(self, v):
        if not isinstance(v, str):
            raise TypeError('input value should be a string type')
        self.__conf['rpc']['netserviceaddr'] = v

    @property
    def rpc_netserviceport(self):
        return int(self.__conf['rpc']['netserviceport'])

    @rpc_netserviceport.setter
    def rpc_netserviceport(self, v):
        if not isinstance(v, int):
            raise TypeError('input value should be an integer type')
        self.__conf['rpc']['netserviceport'] = v

    @property
    def rpc_netservicetrace(self):
        return bool(self.__conf['rpc']['netservicetrace'])

    @rpc_netservicetrace.setter
    def rpc_netservicetrace(self, v):
        if not isinstance(v, bool):
            raise TypeError('input value should be a boolean type')
        self.__conf['rpc']['netservicetrace'] = v

    @property
    def rpc_nstls(self):
        return bool(self.__conf['rpc']['nstls'])

    @rpc_nstls.setter
    def rpc_nstls(self, v):
        if not isinstance(v, bool):
            raise TypeError('input value should be a boolean type')
        self.__conf['rpc']['nstls'] = v

    @property
    def rpc_nscert(self):
        return str(self.__conf['rpc']['nscert'])

    @rpc_nscert.setter
    def rpc_nscert(self, v):
        if not isinstance(v, str):
            raise TypeError('input value should be a string type')
        self.__conf['rpc']['nscert'] = v

    @property
    def rpc_nskey(self):
        return str(self.__conf['rpc']['nskey'])

    @rpc_nskey.setter
    def rpc_nskey(self, v):
        if not isinstance(v, str):
            raise TypeError('input value should be a string type')
        self.__conf['rpc']['nskey'] = v

    @property
    def rpc_nsallowcors(self):
        return bool(self.__conf['rpc']['nsallowcors'])

    @rpc_nsallowcors.setter
    def rpc_nsallowcors(self, v):
        if not isinstance(v, bool):
            raise TypeError('input value should be a boolean type')
        self.__conf['rpc']['nsallowcors'] = v

    @property
    def p2p(self):
        return self.__conf['p2p']

    @property
    def p2p_netprotocoladdr(self):
        return str(self.__conf['p2p']['netprotocoladdr'])

    @p2p_netprotocoladdr.setter
    def p2p_netprotocoladdr(self, v):
        if not isinstance(v, str):
            raise TypeError('input value should be a string type')
        self.__conf['p2p']['netprotocoladdr'] = v

    @property
    def p2p_netprotocolport(self):
        return int(self.__conf['p2p']['netprotocolport'])

    @p2p_netprotocolport.setter
    def p2p_netprotocolport(self, v):
        if not isinstance(v, int):
            raise TypeError('input value should be an integer type')
        self.__conf['p2p']['netprotocolport'] = v

    @property
    def p2p_npbindaddr(self):
        return str(self.__conf['p2p']['npbindaddr'])

    @p2p_npbindaddr.setter
    def p2p_npbindaddr(self, v):
        if not isinstance(v, str):
            raise TypeError('input value should be a string type')
        self.__conf['p2p']['npbindaddr'] = v

    @property
    def p2p_npbindport(self):
        return int(self.__conf['p2p']['npbindport'])

    @p2p_npbindport.setter
    def p2p_npbindport(self, v):
        if not isinstance(v, int):
            raise TypeError('input value should be an integer type')
        self.__conf['p2p']['npbindport'] = v

    @property
    def p2p_nptls(self):
        return bool(self.__conf['p2p']['nptls'])

    @p2p_nptls.setter
    def p2p_nptls(self, v):
        if not isinstance(v, bool):
            raise TypeError('input value should be a boolean type')
        self.__conf['p2p']['nptls'] = v

    @property
    def p2p_npcert(self):
        return str(self.__conf['p2p']['npcert'])

    @p2p_npcert.setter
    def p2p_npcert(self, v):
        if not isinstance(v, str):
            raise TypeError('input value should be a string type')
        self.__conf['p2p']['npcert'] = v

    @property
    def p2p_npkey(self):
        return str(self.__conf['p2p']['npkey'])

    @p2p_npkey.setter
    def p2p_npkey(self, v):
        if not isinstance(v, str):
            raise TypeError('input value should be a string type')
        self.__conf['p2p']['npkey'] = v

    @property
    def p2p_npaddpeers(self):
        return self.__conf['p2p']['npaddpeers']

    @p2p_npaddpeers.setter
    def p2p_npaddpeers(self, v):
        if not isinstance(v, list):
            raise TypeError('input value should be an array type')
        self.__conf['p2p']['npaddpeers'] = v

    @property
    def p2p_nphiddenpeers(self):
        return self.__conf['p2p']['nphiddenpeers']

    @p2p_nphiddenpeers.setter
    def p2p_nphiddenpeers(self, v):
        if not isinstance(v, list):
            raise TypeError('input value should be an array type')
        self.__conf['p2p']['nphiddenpeers'] = v

    @property
    def p2p_npdiscoverpeers(self):
        return bool(self.__conf['p2p']['npdiscoverpeers'])

    @p2p_npdiscoverpeers.setter
    def p2p_npdiscoverpeers(self, v):
        if not isinstance(v, bool):
            raise TypeError('input value should be a boolean type')
        self.__conf['p2p']['npdiscoverpeers'] = v

    @property
    def p2p_npmaxpeers(self):
        return int(self.__conf['p2p']['npmaxpeers'])

    @p2p_npmaxpeers.setter
    def p2p_npmaxpeers(self, v):
        if not isinstance(v, int):
            raise TypeError('input value should be an integer type')
        self.__conf['p2p']['npmaxpeers'] = v

    @property
    def p2p_nppeerpool(self):
        return int(self.__conf['p2p']['nppeerpool'])

    @p2p_nppeerpool.setter
    def p2p_nppeerpool(self, v):
        if not isinstance(v, int):
            raise TypeError('input value should be an integer type')
        self.__conf['p2p']['nppeerpool'] = v

    @property
    def p2p_npexposeself(self):
        return bool(self.__conf['p2p']['npexposeself'])

    @p2p_npexposeself.setter
    def p2p_npexposeself(self, v):
        if not isinstance(v, bool):
            raise TypeError('input value should be a boolean type')
        self.__conf['p2p']['npexposeself'] = v

    @property
    def p2p_npusepolaris(self):
        return bool(self.__conf['p2p']['npusepolaris'])

    @p2p_npusepolaris.setter
    def p2p_npusepolaris(self, v):
        if not isinstance(v, bool):
            raise TypeError('input value should be a boolean type')
        self.__conf['p2p']['npusepolaris'] = v

    @property
    def p2p_npaddpolarises(self):
        return self.__conf['p2p']['npaddpolarises']

    @p2p_npaddpolarises.setter
    def p2p_npaddpolarises(self, v):
        if not isinstance(v, list):
            raise TypeError('input value should be an array type')
        self.__conf['p2p']['npaddpolarises'] = v

    @property
    def p2p_logfullpeerid(self):
        return bool(self.__conf['p2p']['logfullpeerid'])

    @p2p_logfullpeerid.setter
    def p2p_logfullpeerid(self, v):
        if not isinstance(v, bool):
            raise TypeError('input value should be a boolean type')
        self.__conf['p2p']['logfullpeerid'] = v

    @property
    def polaris(self):
        return self.__conf['polaris']

    @property
    def polaris_allowprivate(self):
        return bool(self.__conf['polaris']['allowprivate'])

    @polaris_allowprivate.setter
    def polaris_allowprivate(self, v):
        if not isinstance(v, bool):
            raise TypeError('input value should be a boolean type')
        self.__conf['polaris']['allowprivate'] = v

    @property
    def polaris_genesisfile(self):
        return str(self.__conf['polaris']['genesisfile'])

    @polaris_genesisfile.setter
    def polaris_genesisfile(self, v):
        if not isinstance(v, str):
            raise TypeError('input value should be a string type')
        self.__conf['polaris']['genesisfile'] = v

    @property
    def blockchain(self):
        return self.__conf['blockchain']

    @property
    def blockchain_maxblocksize(self):
        return int(self.__conf['blockchain']['maxblocksize'])

    @blockchain_maxblocksize.setter
    def blockchain_maxblocksize(self, v):
        if not isinstance(v, int):
            raise TypeError('input value should be an integer type')
        self.__conf['blockchain']['maxblocksize'] = v

    @property
    def blockchain_coinbaseaccount(self):
        return str(self.__conf['blockchain']['coinbaseaccount'])

    @blockchain_coinbaseaccount.setter
    def blockchain_coinbaseaccount(self, v):
        if not isinstance(v, str):
            raise TypeError('input value should be a string type')
        self.__conf['blockchain']['coinbaseaccount'] = v

    @property
    def blockchain_maxanchorcount(self):
        return int(self.__conf['blockchain']['maxanchorcount'])

    @blockchain_maxanchorcount.setter
    def blockchain_maxanchorcount(self, v):
        if not isinstance(v, int):
            raise TypeError('input value should be an integer type')
        self.__conf['blockchain']['maxanchorcount'] = v

    @property
    def blockchain_verifiercount(self):
        return int(self.__conf['blockchain']['verifiercount'])

    @blockchain_verifiercount.setter
    def blockchain_verifiercount(self, v):
        if not isinstance(v, int):
            raise TypeError('input value should be an integer type')
        self.__conf['blockchain']['verifiercount'] = v

    @property
    def blockchain_forceresetheight(self):
        return int(self.__conf['blockchain']['forceresetheight'])

    @blockchain_forceresetheight.setter
    def blockchain_forceresetheight(self, v):
        if not isinstance(v, int):
            raise TypeError('input value should be an integer type')
        self.__conf['blockchain']['forceresetheight'] = v

    @property
    def blockchain_fixedtxfee(self):
        return str(self.__conf['blockchain']['fixedtxfee'])

    @blockchain_fixedtxfee.setter
    def blockchain_fixedtxfee(self, v):
        if not isinstance(v, str):
            raise TypeError('input value should be a string type')
        self.__conf['blockchain']['fixedtxfee'] = v

    @property
    def mempool(self):
        return self.__conf['mempool']

    @property
    def mempool_showmetrics(self):
        return bool(self.__conf['mempool']['showmetrics'])

    @mempool_showmetrics.setter
    def mempool_showmetrics(self, v):
        if not isinstance(v, bool):
            raise TypeError('input value should be a boolean type')
        self.__conf['mempool']['showmetrics'] = v

    @property
    def mempool_enablefadeout(self):
        return bool(self.__conf['mempool']['enablefadeout'])

    @mempool_enablefadeout.setter
    def mempool_enablefadeout(self, v):
        if not isinstance(v, bool):
            raise TypeError('input value should be a boolean type')
        self.__conf['mempool']['enablefadeout'] = v

    @property
    def mempool_fadeoutperiod(self):
        return int(self.__conf['mempool']['fadeoutperiod'])

    @mempool_fadeoutperiod.setter
    def mempool_fadeoutperiod(self, v):
        if not isinstance(v, int):
            raise TypeError('input value should be an integer type')
        self.__conf['mempool']['fadeoutperiod'] = v

    @property
    def mempool_verifiers(self):
        return int(self.__conf['mempool']['verifiers'])

    @mempool_verifiers.setter
    def mempool_verifiers(self, v):
        if not isinstance(v, int):
            raise TypeError('input value should be an integer type')
        self.__conf['mempool']['verifiers'] = v

    @property
    def mempool_dumpfilepath(self):
        return str(self.__conf['mempool']['dumpfilepath'])

    @mempool_dumpfilepath.setter
    def mempool_dumpfilepath(self, v):
        if not isinstance(v, str):
            raise TypeError('input value should be a string type')
        self.__conf['mempool']['dumpfilepath'] = v

    @property
    def consensus(self):
        return self.__conf['consensus']

    @property
    def consensus_enablebp(self):
        return bool(self.__conf['consensus']['enablebp'])

    @consensus_enablebp.setter
    def consensus_enablebp(self, v):
        if not isinstance(v, bool):
            raise TypeError('input value should be a boolean type')
        self.__conf['consensus']['enablebp'] = v

    @property
    def consensus_blockinterval(self):
        return int(self.__conf['consensus']['blockinterval'])

    @consensus_blockinterval.setter
    def consensus_blockinterval(self, v):
        if not isinstance(v, int):
            raise TypeError('input value should be an integer type')
        self.__conf['consensus']['blockinterval'] = v

    @property
    def consensus_raft(self):
        return self.__conf['consensus']['raft']

    @consensus_raft.setter
    def consensus_raft(self, v):
        self.__conf['consensus']['raft'] = v

    @property
    def monitor(self):
        return self.__conf['monitor']

    @property
    def monitor_protocol(self):
        return str(self.__conf['monitor']['protocol'])

    @monitor_protocol.setter
    def monitor_protocol(self, v):
        if not isinstance(v, str):
            raise TypeError('input value should be a string type')
        self.__conf['monitor']['protocol'] = v

    @property
    def monitor_endpoint(self):
        return str(self.__conf['monitor']['endpoint'])

    @monitor_endpoint.setter
    def monitor_endpoint(self, v):
        if not isinstance(v, str):
            raise TypeError('input value should be a string type')
        self.__conf['monitor']['endpoint'] = v

    @property
    def account(self):
        return self.__conf['account']

    @property
    def account_unlocktimeout(self):
        return int(self.__conf['account']['unlocktimeout'])

    @account_unlocktimeout.setter
    def account_unlocktimeout(self, v):
        if not isinstance(v, int):
            raise TypeError('input value should be an integer type')
        self.__conf['account']['unlocktimeout'] = v





# -*- coding: utf-8 -*-

import json


class ChainID:
    def __init__(self, chain_id):
        self._chain_id = chain_id

    @property
    def magic(self):
        return self._chain_id.magic

    @property
    def is_public(self):
        return self._chain_id.public

    @property
    def is_mainnet(self):
        return self._chain_id.mainnet

    @property
    def consensus(self):
        return self._chain_id.consensus

    def json(self):
        return {
            'magic': self.magic,
            'is_public': self.is_public,
            'is_mainnet': self.is_mainnet,
            'consensus': self.consensus,
        }

    def __str__(self):
        return json.dumps(self.json(), indent=2)




import pytest

from aergo.herapy.obj.tx_result import TxResult, TxResultType,\
    TxResultStatus, CommitStatus
from aergo.herapy.grpc import rpc_pb2, blockchain_pb2
from aergo.herapy.utils.encoding import encode_tx_hash, encode_address


def test_grpc_receipt():
    grpc_result1 = blockchain_pb2.Receipt()
    all_fields = grpc_result1.DESCRIPTOR.fields_by_name
    '''
    for key in all_fields.keys():
        one_field = all_fields[key]
        print('Key[{}]: Type[{}]'.format(key, str(one_field.type)))
    '''
    assert len(all_fields.keys()) == 13

    receipt = {
        'contractAddress': b'contract_address',
        'status': 'CREATED',
        'ret': 'result_ret',
        'txHash': b'tx_hash',
        'feeUsed': b'fee_used',
        'cumulativeFeeUsed': b'cumulative_fee_used',
        'bloom': b'result_bloom',
        'blockNo': 10,
        'blockHash': b'block_hash',
        'txIndex': 1,
        'from': b'result_from',
        'to': b'result_to',
    }
    grpc_result2 = blockchain_pb2.Receipt(**receipt)
    tx_result2 = TxResult(grpc_result2)
    assert tx_result2.type == TxResultType.RECEIPT
    assert tx_result2.status == TxResultStatus.CREATED
    assert tx_result2.detail == receipt['ret']
    assert tx_result2.contract_address == encode_address(receipt['contractAddress'])

    grpc_result3 = blockchain_pb2.Receipt()
    grpc_result3.contractAddress = b'contract_address'
    grpc_result3.status = b'result_status'
    grpc_result3.ret = b'result_ret'
    grpc_result3.txHash = b'tx_hash'
    grpc_result3.feeUsed = b'fee_used'
    grpc_result3.cumulativeFeeUsed = b'cumulative_fee_used'
    grpc_result3.bloom = b'result_bloom'
    grpc_result3.blockNo = 10
    grpc_result3.blockHash = b'block_hash'
    grpc_result3.txIndex = 1
    #grpc_result3.from = b'result_from'
    setattr(grpc_result3, 'from', b'result_from')
    grpc_result3.to = b'result_to'
    assert len(grpc_result3.events) == 0
    events = []
    grpc_result3.events.extend(events)
    assert len(grpc_result3.events) == 0
    # TODO: add events

    assert grpc_result3.contractAddress == grpc_result2.contractAddress
    assert grpc_result3.contractAddress == receipt['contractAddress']
    assert grpc_result3.status != grpc_result2.status
    assert grpc_result3.status != receipt['status']
    assert grpc_result3.ret == grpc_result2.ret
    assert grpc_result3.ret == receipt['ret']
    assert grpc_result3.txHash == grpc_result2.txHash
    assert grpc_result3.txHash == receipt['txHash']
    assert grpc_result3.feeUsed == grpc_result2.feeUsed
    assert grpc_result3.feeUsed == receipt['feeUsed']
    assert grpc_result3.cumulativeFeeUsed == grpc_result2.cumulativeFeeUsed
    assert grpc_result3.cumulativeFeeUsed == receipt['cumulativeFeeUsed']
    assert grpc_result3.bloom == grpc_result2.bloom
    assert grpc_result3.bloom == receipt['bloom']
    assert grpc_result3.blockNo == grpc_result2.blockNo
    assert grpc_result3.blockNo == receipt['blockNo']
    assert grpc_result3.blockHash == grpc_result2.blockHash
    assert grpc_result3.blockHash == receipt['blockHash']
    assert grpc_result3.txIndex == grpc_result2.txIndex
    assert grpc_result3.txIndex == receipt['txIndex']
    #assert grpc_result3.from == grpc_result2.from
    assert getattr(grpc_result3, 'from') == getattr(grpc_result2, 'from')
    #assert grpc_result3.from == receipt['to']
    assert getattr(grpc_result3, 'from') == receipt['from']
    assert grpc_result3.to == grpc_result2.to
    assert grpc_result3.to == receipt['to']

    tx_result3 = TxResult(grpc_result3)
    assert tx_result3.type == TxResultType.RECEIPT
    assert tx_result3.status == TxResultStatus.ERROR
    assert tx_result3.detail == grpc_result3.status
    assert tx_result3.contract_address == encode_address(receipt['contractAddress'])

    grpc_result3.status = 'CREATED'
    grpc_result3.ret = 'error is occurred'
    tx_result3 = TxResult(grpc_result3)
    assert tx_result3.status != TxResultStatus.SUCCESS
    assert tx_result3.status == TxResultStatus.CREATED
    assert tx_result3.detail == 'error is occurred'

    grpc_result3.status = 'SUCCESS'
    grpc_result3.ret = 'error is occurred'
    tx_result3 = TxResult(grpc_result3)
    assert tx_result3.status == TxResultStatus.SUCCESS
    assert tx_result3.status != TxResultStatus.ERROR
    assert tx_result3.detail == grpc_result3.ret


def test_grpc_commit_result():
    grpc_result = rpc_pb2.CommitResult()
    all_fields = grpc_result.DESCRIPTOR.fields_by_name
    '''
    for key in all_fields.keys():
        one_field = all_fields[key]
        print('Key[{}]: Type[{}]'.format(key, str(one_field.type)))
    '''
    assert len(all_fields.keys()) == 3

    grpc_result.hash = b'commit_result_hash'
    grpc_result.error = rpc_pb2.TX_NONCE_TOO_LOW
    grpc_result.detail = b'commit_result_detail'

    tx_result = TxResult(grpc_result)
    assert tx_result.type == TxResultType.COMMIT_RESULT
    assert tx_result.tx_id == encode_tx_hash(b'commit_result_hash')
    assert tx_result.status == CommitStatus.TX_NONCE_TOO_LOW
    assert tx_result.detail == 'commit_result_detail'



import sys
import traceback
import json

import aergo.herapy as herapy


def eprint(*args, **kwargs):
    print(*args, file=sys.stderr, **kwargs)
    print(*args, **kwargs)


def run():
    try:
        aergo1 = herapy.Aergo()
        aergo2 = herapy.Aergo()
        aergo3 = herapy.Aergo()
        aergo4 = herapy.Aergo()

        print("------ Connect AERGO -----------")
        """
        aergo1.connect('localhost:17801')
        aergo2.connect('localhost:17802')
        aergo3.connect('localhost:17803')
        """
        aergo1.connect('ec2-52-56-86-84.eu-west-2.compute.amazonaws.com:17845')
        aergo2.connect('ec2-13-57-31-165.us-west-1.compute.amazonaws.com:17845')
        aergo3.connect('ec2-3-86-18-207.compute-1.amazonaws.com:17845')
        aergo4.connect('ec2-54-180-100-160.ap-northeast-2.compute.amazonaws.com:17845')

        print("------ Get Blockchain Status -----------")
        best_block_hash, best_block_height = aergo1.get_blockchain_status()
        print("(aergo1) Best Block Hash      = {}".format(best_block_hash))
        print("(aergo1) Best Block Height    = {}".format(best_block_height))

        best_block_hash, best_block_height = aergo2.get_blockchain_status()
        print("(aergo2) Best Block Hash      = {}".format(best_block_hash))
        print("(aergo2) Best Block Height    = {}".format(best_block_height))

        best_block_hash, best_block_height = aergo3.get_blockchain_status()
        print("(aergo3) Best Block Hash      = {}".format(best_block_hash))
        print("(aergo3) Best Block Height    = {}".format(best_block_height))

        best_block_hash, best_block_height = aergo4.get_blockchain_status()
        print("(aergo4) Best Block Hash      = {}".format(best_block_hash))
        print("(aergo4) Best Block Height    = {}".format(best_block_height))

        print("------ Get Block Status -----------")
        best_block_height = best_block_height - 2
        block1 = aergo1.get_block(block_height=best_block_height)
        print("Aergo 1:\n{}".format(str(block1.hash)))
        block2 = aergo2.get_block(block_height=best_block_height)
        print("Aergo 2:\n{}".format(str(block2.hash)))
        block3 = aergo3.get_block(block_height=best_block_height)
        print("Aergo 3:\n{}".format(str(block3.hash)))
        block4 = aergo4.get_block(block_height=best_block_height)
        print("Aergo 4:\n{}".format(str(block4.hash)))

        aergo1.disconnect()
        aergo2.disconnect()
        aergo3.disconnect()
        aergo4.disconnect()
    except Exception as e:
        eprint(e)
        traceback.print_exception(*sys.exc_info())


if __name__ == '__main__':
    run()
